@@ -150,10 +150,12 @@ class LiMePlots:
             defaultConf = DARK_PLOT.copy()
             foreground = defaultConf['text.color']
             color_fit = 'yellow'
+            err_shade = 'tab:yellow'
         else:
             defaultConf = STANDARD_PLOT.copy()
             foreground = 'black'
             color_fit = 'tab:blue'
+            err_shade = 'tab:blue'
 
         # Plot Configuration
         defaultConf.update(fig_conf)
@@ -247,7 +249,7 @@ class LiMePlots:
 
             label = r'$\sigma_{Continuum}/\overline{F(cont)}$'
             y_low, y_high = -self.std_cont / self.cont, self.std_cont / self.cont
-            ax[1].fill_between(x_in/z_cor, y_low*z_cor, y_high*z_cor, facecolor='yellow', alpha=0.2, label=label)
+            ax[1].fill_between(x_in/z_cor, y_low*z_cor, y_high*z_cor, facecolor=err_shade, alpha=0.3, label=label)
 
             # Residual plot labeling
             ax[1].set_xlim(ax[0].get_xlim())
@@ -479,110 +481,6 @@ class LiMePlots:
 
         return
 
-    def table_fluxes(self, lines_df, table_address, pyneb_rc=None, scaleTable=1000):
-
-        # TODO this could be included in sr.print
-        tex_address = f'{table_address}'
-        txt_address = f'{table_address}.txt'
-
-        # Measure line fluxes
-        pdf = PdfMaker()
-        pdf.create_pdfDoc(pdf_type='table')
-        pdf.pdf_insert_table(FLUX_TEX_TABLE_HEADERS)
-
-        # Dataframe as container as a txt file
-        tableDF = pd.DataFrame(columns=FLUX_TXT_TABLE_HEADERS[1:])
-
-        # Normalization line
-        if 'H1_4861A' in lines_df.index:
-            flux_Hbeta = lines_df.loc['H1_4861A', 'intg_flux']
-        else:
-            flux_Hbeta = scaleTable
-
-        obsLines = lines_df.index.values
-        for lineLabel in obsLines:
-
-            label_entry = lines_df.loc[lineLabel, 'latexLabel']
-            wavelength = lines_df.loc[lineLabel, 'wavelength']
-            eqw, eqwErr = lines_df.loc[lineLabel, 'eqw'], lines_df.loc[lineLabel, 'eqw_err']
-
-            flux_intg = lines_df.loc[lineLabel, 'intg_flux'] / flux_Hbeta * scaleTable
-            flux_intgErr = lines_df.loc[lineLabel, 'intg_err'] / flux_Hbeta * scaleTable
-            flux_gauss = lines_df.loc[lineLabel, 'gauss_flux'] / flux_Hbeta * scaleTable
-            flux_gaussErr = lines_df.loc[lineLabel, 'gauss_err'] / flux_Hbeta * scaleTable
-
-            if (lines_df.loc[lineLabel, 'blended_label'] != 'None') and ('_m' not in lineLabel):
-                flux, fluxErr = flux_gauss, flux_gaussErr
-                label_entry = label_entry + '$_{gauss}$'
-            else:
-                flux, fluxErr = flux_intg, flux_intgErr
-
-            # Correct the flux
-            if pyneb_rc is not None:
-                corr = pyneb_rc.getCorrHb(wavelength)
-                intensity, intensityErr = flux * corr, fluxErr * corr
-                intensity_entry = r'${:0.2f}\,\pm\,{:0.2f}$'.format(intensity, intensityErr)
-            else:
-                intensity, intensityErr = '-', '-'
-                intensity_entry = '-'
-
-            eqw_entry = r'${:0.2f}\,\pm\,{:0.2f}$'.format(eqw, eqwErr)
-            flux_entry = r'${:0.2f}\,\pm\,{:0.2f}$'.format(flux, fluxErr)
-
-            # Add row of data
-            tex_row_i = [label_entry, eqw_entry, flux_entry, intensity_entry]
-            txt_row_i = [label_entry, eqw, eqwErr, flux, fluxErr, intensity, intensityErr]
-
-            lastRow_check = True if lineLabel == obsLines[-1] else False
-            pdf.addTableRow(tex_row_i, last_row=lastRow_check)
-            tableDF.loc[lineLabel] = txt_row_i[1:]
-
-        if pyneb_rc is not None:
-
-            # Data last rows
-            row_Hbetaflux = [r'$H\beta$ $(erg\,cm^{-2} s^{-1} \AA^{-1})$',
-                             '',
-                             flux_Hbeta,
-                             flux_Hbeta * pyneb_rc.getCorr(4861)]
-
-            row_cHbeta = [r'$c(H\beta)$',
-                          '',
-                          float(pyneb_rc.cHbeta),
-                          '']
-        else:
-            # Data last rows
-            row_Hbetaflux = [r'$H\beta$ $(erg\,cm^{-2} s^{-1} \AA^{-1})$',
-                             '',
-                             flux_Hbeta,
-                             '-']
-
-            row_cHbeta = [r'$c(H\beta)$',
-                          '',
-                          '-',
-                          '']
-
-        pdf.addTableRow(row_Hbetaflux, last_row=False)
-        pdf.addTableRow(row_cHbeta, last_row=False)
-        tableDF.loc[row_Hbetaflux[0]] = row_Hbetaflux[1:] + [''] * 3
-        tableDF.loc[row_cHbeta[0]] = row_cHbeta[1:] + [''] * 3
-
-        # Format last rows
-        pdf.table.add_hline()
-        pdf.table.add_hline()
-
-        # Save the pdf table
-        try:
-            pdf.generate_pdf(table_address, clean_tex=True)
-        except:
-            print('-- PDF compilation failure')
-
-        # Save the txt table
-        with open(txt_address, 'wb') as output_file:
-            string_DF = tableDF.to_string()
-            string_DF = string_DF.replace('$', '')
-            output_file.write(string_DF.encode('UTF-8'))
-
-        return
 
     def table_kinematics(self, lines_df, table_address, flux_normalization=1.0):
 
